@@ -408,6 +408,12 @@ class Cursor(DBAPICursor):
         rows_to_return.append(read_values_from_array(self._query_columns_description, dis))
         return rows_to_return
 
+    def explain(self):
+        return self.connection.client.explain(self._query_id)
+
+    def explain_analyse(self):
+        return self.connection.client.explainAnalyze(self._query_id)
+
 
 def poll(self, get_progress_update=True):
     """Poll for and return the raw status data provided by the Hive Thrift REST API.
@@ -433,10 +439,17 @@ def fetch_logs(self):
 class Error(Exception):
     pass
 
+#
+# Type Objects and Constructors
+#
+
+for type_id in PRIMITIVE_TYPES:
+    name = TypeId._VALUES_TO_NAMES[type_id]
+    setattr(sys.modules[__name__], name, DBAPITypeObject([name]))
+
 
 if __name__ == '__main__':
-    # host = '18.212.241.241'
-    host = '54.226.47.223'
+    host = '54.196.55.54'
     e6x_connection = connect(
         host=host,
         port=9000,
@@ -453,17 +466,18 @@ if __name__ == '__main__':
     )
     print('Connected.')
     import time
+
     start = time.time()
     cursor = e6x_connection.cursor()
-    query = 'SELECT * FROM web_sales limit 10'
+
+    query = 'select * from date_dim limit 2'
     query_id = cursor.execute(query)
-    print(query_id)
-    # cursor.cancel(query_id)
+    print('query_id', query_id)
     all_records = cursor.fetchall()
-    print('Execution time', time.time() - start)
-    print('Length', len(all_records))
+    print(time.time() - start)
     print(all_records)
-    # e6x_connection.close()
+    print(cursor.explain_analyse())
+    e6x_connection.close()
 #
 #     e6x_connection.reopen()
 #
@@ -476,10 +490,4 @@ if __name__ == '__main__':
 #
 #     e6x_connection.close()
 
-#
-# Type Objects and Constructors
-#
 
-for type_id in PRIMITIVE_TYPES:
-    name = TypeId._VALUES_TO_NAMES[type_id]
-    setattr(sys.modules[__name__], name, DBAPITypeObject([name]))
